pub enum InviteKeyBundleError {
DecodingFailed,
KeySealingFailed,
KeyUnsealingFailed,
MissingKeyId(String),
InvalidPrivateKey,
ConfirmationNotEnabled,
}Expand description
Errors that can occur when creating or opening an invite.
Variants
DecodingFailed
Decoding the encrypted invite failed
KeySealingFailed
Sealing one of the invite’s envelopes failed
KeyUnsealingFailed
Opening one of the invite’s envelopes failed
MissingKeyId(String)
A required key was not found in the key store context
InvalidPrivateKey
The organization private key could not be unwrapped, or its public-key thumbprint could not be derived
ConfirmationNotEnabled
The organization key cannot be recovered from the invite because confirmation is disabled